#!/usr/bin/perl
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use lib "t/lib";
use MooseCompat;

use strict;
use warnings;

use Test::More;

=pod

This just makes sure that the Bar gets
a metaclass initialized for it correctly.

=cut

{
    package Foo;
    use Mouse;

    package Bar;
    use strict;
    use warnings;

    use base 'Foo';
}

my $bar = Bar->new;
isa_ok($bar, 'Bar');
isa_ok($bar, 'Foo');

done_testing;
