package Bar7::Meta::Trait2;
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use MooseCompat;
use Mouse::Role;

has foo => (
    traits  => ['Array'],
    handles => {
        push_foo => 'push',
    },
);

no Mouse::Role;

1;
