package Role::Interface;
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use MooseCompat;
use Mouse::Role;

requires "meth2";

1;
