#!/usr/bin/perl
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use lib "t/lib";
use MooseCompat;

use strict;
use warnings;

use Test::More;
use Test::Exception;

lives_ok {
    package MouseX::Attribute::Test;
    use Mouse::Role;
} 'creating custom attribute "metarole" is okay';

lives_ok {
    package Mouse::Meta::Attribute::Custom::Test;
    use Mouse;

    extends 'Mouse::Meta::Attribute';
    with 'MouseX::Attribute::Test';
} 'custom attribute metaclass extending role is okay';

done_testing;
