package Mouse::Meta::Attribute::Custom::Foo;
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use MooseCompat;

use Mouse::Role;

1;
